@@ -27,13 +27,13 @@ class EmailMessageManager(models.Manager):
         return models.QuerySet(self.model, using=self._db)
 
     @atomic
-    def reset_tasks_to_initial_status(self) -> None:
+    def reset_messages(self) -> None:
         self.get_queryset().select_for_update().filter(
             status=EmailMessage.Statuses.in_sending
         ).update(status=EmailMessage.Statuses.new)
 
     @atomic
-    def select_for_process(self, count: int) -> models.QuerySet:
+    def choose_to_send(self, count: int) -> models.QuerySet:
         base_qs = (
             self.get_queryset()
                 .select_for_update()
